@@ -10,9 +10,10 @@ class CreatedMixin(models.Model):
 
 
 def NameField(**kwargs):
+    unique = kwargs.pop("unique", True)
     return models.CharField(
         max_length=512,
-        unique=True,
+        unique=unique,
         validators=(
             validators.RegexValidator(
                 regex=r"^[a-zA-Z0-9\- ()ßàÀéÉèÈäÄëËïÏöÖüÜçÇâÂêÊîÎôÔûÛ']*$",
@@ -26,10 +27,11 @@ def NameField(**kwargs):
 
 
 def CodeField(lower=True, **kwargs):
+    unique = kwargs.pop("unique", True)
     char_set = "a-z" if lower else "A-Z"
     return models.CharField(
         max_length=32,
-        unique=True,
+        unique=unique,
         validators=(
             validators.RegexValidator(
                 regex=rf"^[{char_set}0-9_]*$",
